# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/canbus/proto/devkit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/canbus/proto/devkit.proto',
  package='apollo.canbus',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!modules/canbus/proto/devkit.proto\x12\rapollo.canbus\"\x88\x02\n\x14Throttle_command_100\x12\x14\n\x0cthrottle_acc\x18\x01 \x01(\x01\x12\x14\n\x0c\x63hecksum_100\x18\x02 \x01(\x05\x12\x1d\n\x15throttle_pedal_target\x18\x03 \x01(\x01\x12R\n\x10throttle_en_ctrl\x18\x04 \x01(\x0e\x32\x38.apollo.canbus.Throttle_command_100.Throttle_en_ctrlType\"Q\n\x14Throttle_en_ctrlType\x12\x1c\n\x18THROTTLE_EN_CTRL_DISABLE\x10\x00\x12\x1b\n\x17THROTTLE_EN_CTRL_ENABLE\x10\x01\"\x80\x03\n\x11\x42rake_command_101\x12\x11\n\tbrake_dec\x18\x01 \x01(\x01\x12\x14\n\x0c\x63hecksum_101\x18\x02 \x01(\x05\x12\x1a\n\x12\x62rake_pedal_target\x18\x03 \x01(\x01\x12I\n\rbrake_en_ctrl\x18\x04 \x01(\x0e\x32\x32.apollo.canbus.Brake_command_101.Brake_en_ctrlType\x12\x45\n\x0b\x61\x65\x62_en_ctrl\x18\x05 \x01(\x0e\x32\x30.apollo.canbus.Brake_command_101.Aeb_en_ctrlType\"J\n\x0f\x41\x65\x62_en_ctrlType\x12\x1b\n\x17\x41\x45\x42_EN_CTRL_DISABLE_AEB\x10\x00\x12\x1a\n\x16\x41\x45\x42_EN_CTRL_ENABLE_AEB\x10\x01\"H\n\x11\x42rake_en_ctrlType\x12\x19\n\x15\x42RAKE_EN_CTRL_DISABLE\x10\x00\x12\x18\n\x14\x42RAKE_EN_CTRL_ENABLE\x10\x01\"\xf9\x01\n\x14Steering_command_102\x12L\n\rsteer_en_ctrl\x18\x01 \x01(\x0e\x32\x35.apollo.canbus.Steering_command_102.Steer_en_ctrlType\x12\x1a\n\x12steer_angle_target\x18\x02 \x01(\x05\x12\x17\n\x0fsteer_angle_spd\x18\x03 \x01(\x05\x12\x14\n\x0c\x63hecksum_102\x18\x04 \x01(\x05\"H\n\x11Steer_en_ctrlType\x12\x19\n\x15STEER_EN_CTRL_DISABLE\x10\x00\x12\x18\n\x14STEER_EN_CTRL_ENABLE\x10\x01\"\x89\x03\n\x10Gear_command_103\x12\x44\n\x0bgear_target\x18\x01 \x01(\x0e\x32/.apollo.canbus.Gear_command_103.Gear_targetType\x12\x46\n\x0cgear_en_ctrl\x18\x02 \x01(\x0e\x32\x30.apollo.canbus.Gear_command_103.Gear_en_ctrlType\x12\x14\n\x0c\x63hecksum_103\x18\x03 \x01(\x05\"\x89\x01\n\x0fGear_targetType\x12\x17\n\x13GEAR_TARGET_INVALID\x10\x00\x12\x14\n\x10GEAR_TARGET_PARK\x10\x01\x12\x17\n\x13GEAR_TARGET_REVERSE\x10\x02\x12\x17\n\x13GEAR_TARGET_NEUTRAL\x10\x03\x12\x15\n\x11GEAR_TARGET_DRIVE\x10\x04\"E\n\x10Gear_en_ctrlType\x12\x18\n\x14GEAR_EN_CTRL_DISABLE\x10\x00\x12\x17\n\x13GEAR_EN_CTRL_ENABLE\x10\x01\"\xca\x02\n\x10Park_command_104\x12\x14\n\x0c\x63hecksum_104\x18\x01 \x01(\x05\x12\x44\n\x0bpark_target\x18\x02 \x01(\x0e\x32/.apollo.canbus.Park_command_104.Park_targetType\x12\x46\n\x0cpark_en_ctrl\x18\x03 \x01(\x0e\x32\x30.apollo.canbus.Park_command_104.Park_en_ctrlType\"K\n\x0fPark_targetType\x12\x17\n\x13PARK_TARGET_RELEASE\x10\x00\x12\x1f\n\x1bPARK_TARGET_PARKING_TRIGGER\x10\x01\"E\n\x10Park_en_ctrlType\x12\x18\n\x14PARK_EN_CTRL_DISABLE\x10\x00\x12\x17\n\x13PARK_EN_CTRL_ENABLE\x10\x01\"\xfa\x04\n\x13Throttle_report_500\x12\x1d\n\x15throttle_pedal_actual\x18\x01 \x01(\x01\x12K\n\rthrottle_flt2\x18\x02 \x01(\x0e\x32\x34.apollo.canbus.Throttle_report_500.Throttle_flt2Type\x12K\n\rthrottle_flt1\x18\x03 \x01(\x0e\x32\x34.apollo.canbus.Throttle_report_500.Throttle_flt1Type\x12S\n\x11throttle_en_state\x18\x04 \x01(\x0e\x32\x38.apollo.canbus.Throttle_report_500.Throttle_en_stateType\"b\n\x11Throttle_flt2Type\x12\x1a\n\x16THROTTLE_FLT2_NO_FAULT\x10\x00\x12\x31\n-THROTTLE_FLT2_DRIVE_SYSTEM_COMUNICATION_FAULT\x10\x01\"^\n\x11Throttle_flt1Type\x12\x1a\n\x16THROTTLE_FLT1_NO_FAULT\x10\x00\x12-\n)THROTTLE_FLT1_DRIVE_SYSTEM_HARDWARE_FAULT\x10\x01\"\x90\x01\n\x15Throttle_en_stateType\x12\x1c\n\x18THROTTLE_EN_STATE_MANUAL\x10\x00\x12\x1a\n\x16THROTTLE_EN_STATE_AUTO\x10\x01\x12\x1e\n\x1aTHROTTLE_EN_STATE_TAKEOVER\x10\x02\x12\x1d\n\x19THROTTLE_EN_STATE_STANDBY\x10\x03\"\xb8\x04\n\x10\x42rake_report_501\x12\x1a\n\x12\x62rake_pedal_actual\x18\x01 \x01(\x01\x12\x42\n\nbrake_flt2\x18\x02 \x01(\x0e\x32..apollo.canbus.Brake_report_501.Brake_flt2Type\x12\x42\n\nbrake_flt1\x18\x03 \x01(\x0e\x32..apollo.canbus.Brake_report_501.Brake_flt1Type\x12J\n\x0e\x62rake_en_state\x18\x04 \x01(\x0e\x32\x32.apollo.canbus.Brake_report_501.Brake_en_stateType\"Y\n\x0e\x42rake_flt2Type\x12\x17\n\x13\x42RAKE_FLT2_NO_FAULT\x10\x00\x12.\n*BRAKE_FLT2_BRAKE_SYSTEM_COMUNICATION_FAULT\x10\x01\"U\n\x0e\x42rake_flt1Type\x12\x17\n\x13\x42RAKE_FLT1_NO_FAULT\x10\x00\x12*\n&BRAKE_FLT1_BRAKE_SYSTEM_HARDWARE_FAULT\x10\x01\"\x81\x01\n\x12\x42rake_en_stateType\x12\x19\n\x15\x42RAKE_EN_STATE_MANUAL\x10\x00\x12\x17\n\x13\x42RAKE_EN_STATE_AUTO\x10\x01\x12\x1b\n\x17\x42RAKE_EN_STATE_TAKEOVER\x10\x02\x12\x1a\n\x16\x42RAKE_EN_STATE_STANDBY\x10\x03\"\xe4\x04\n\x13Steering_report_502\x12\x1e\n\x16steer_angle_spd_actual\x18\x01 \x01(\x05\x12\x45\n\nsteer_flt2\x18\x02 \x01(\x0e\x32\x31.apollo.canbus.Steering_report_502.Steer_flt2Type\x12\x45\n\nsteer_flt1\x18\x03 \x01(\x0e\x32\x31.apollo.canbus.Steering_report_502.Steer_flt1Type\x12M\n\x0esteer_en_state\x18\x04 \x01(\x0e\x32\x35.apollo.canbus.Steering_report_502.Steer_en_stateType\x12\x1a\n\x12steer_angle_actual\x18\x05 \x01(\x05\"Y\n\x0eSteer_flt2Type\x12\x17\n\x13STEER_FLT2_NO_FAULT\x10\x00\x12.\n*STEER_FLT2_STEER_SYSTEM_COMUNICATION_FAULT\x10\x01\"U\n\x0eSteer_flt1Type\x12\x17\n\x13STEER_FLT1_NO_FAULT\x10\x00\x12*\n&STEER_FLT1_STEER_SYSTEM_HARDWARE_FAULT\x10\x01\"\x81\x01\n\x12Steer_en_stateType\x12\x19\n\x15STEER_EN_STATE_MANUAL\x10\x00\x12\x17\n\x13STEER_EN_STATE_AUTO\x10\x01\x12\x1b\n\x17STEER_EN_STATE_TAKEOVER\x10\x02\x12\x1a\n\x16STEER_EN_STATE_STANDBY\x10\x03\"\xdc\x02\n\x0fGear_report_503\x12=\n\x08gear_flt\x18\x01 \x01(\x0e\x32+.apollo.canbus.Gear_report_503.Gear_fltType\x12\x43\n\x0bgear_actual\x18\x02 \x01(\x0e\x32..apollo.canbus.Gear_report_503.Gear_actualType\"9\n\x0cGear_fltType\x12\x15\n\x11GEAR_FLT_NO_FAULT\x10\x00\x12\x12\n\x0eGEAR_FLT_FAULT\x10\x01\"\x89\x01\n\x0fGear_actualType\x12\x17\n\x13GEAR_ACTUAL_INVALID\x10\x00\x12\x14\n\x10GEAR_ACTUAL_PARK\x10\x01\x12\x17\n\x13GEAR_ACTUAL_REVERSE\x10\x02\x12\x17\n\x13GEAR_ACTUAL_NEUTRAL\x10\x03\x12\x15\n\x11GEAR_ACTUAL_DRIVE\x10\x04\"\xac\x02\n\x0fPark_report_504\x12I\n\x0eparking_actual\x18\x01 \x01(\x0e\x32\x31.apollo.canbus.Park_report_504.Parking_actualType\x12=\n\x08park_flt\x18\x02 \x01(\x0e\x32+.apollo.canbus.Park_report_504.Park_fltType\"T\n\x12Parking_actualType\x12\x1a\n\x16PARKING_ACTUAL_RELEASE\x10\x00\x12\"\n\x1ePARKING_ACTUAL_PARKING_TRIGGER\x10\x01\"9\n\x0cPark_fltType\x12\x15\n\x11PARK_FLT_NO_FAULT\x10\x00\x12\x12\n\x0ePARK_FLT_FAULT\x10\x01\"\xfa\x05\n\x0eVcu_report_505\x12P\n\x12vehicle_mode_state\x18\x01 \x01(\x0e\x32\x34.apollo.canbus.Vcu_report_505.Vehicle_mode_stateType\x12L\n\x10\x66rontcrash_state\x18\x02 \x01(\x0e\x32\x32.apollo.canbus.Vcu_report_505.Frontcrash_stateType\x12J\n\x0f\x62\x61\x63kcrash_state\x18\x03 \x01(\x0e\x32\x31.apollo.canbus.Vcu_report_505.Backcrash_stateType\x12>\n\taeb_state\x18\x04 \x01(\x0e\x32+.apollo.canbus.Vcu_report_505.Aeb_stateType\x12\x0b\n\x03\x61\x63\x63\x18\x05 \x01(\x01\x12\r\n\x05speed\x18\x06 \x01(\x01\"\xb1\x01\n\x16Vehicle_mode_stateType\x12)\n%VEHICLE_MODE_STATE_MANUAL_REMOTE_MODE\x10\x00\x12 \n\x1cVEHICLE_MODE_STATE_AUTO_MODE\x10\x01\x12%\n!VEHICLE_MODE_STATE_EMERGENCY_MODE\x10\x02\x12#\n\x1fVEHICLE_MODE_STATE_STANDBY_MODE\x10\x03\"W\n\x14\x46rontcrash_stateType\x12\x1d\n\x19\x46RONTCRASH_STATE_NO_EVENT\x10\x00\x12 \n\x1c\x46RONTCRASH_STATE_CRASH_EVENT\x10\x01\"T\n\x13\x42\x61\x63kcrash_stateType\x12\x1c\n\x18\x42\x41\x43KCRASH_STATE_NO_EVENT\x10\x00\x12\x1f\n\x1b\x42\x41\x43KCRASH_STATE_CRASH_EVENT\x10\x01\"=\n\rAeb_stateType\x12\x16\n\x12\x41\x45\x42_STATE_INACTIVE\x10\x00\x12\x14\n\x10\x41\x45\x42_STATE_ACTIVE\x10\x01\"G\n\x15Wheelspeed_report_506\x12\n\n\x02rr\x18\x01 \x01(\x01\x12\n\n\x02rl\x18\x02 \x01(\x01\x12\n\n\x02\x66r\x18\x03 \x01(\x01\x12\n\n\x02\x66l\x18\x04 \x01(\x01\"\x81\x01\n\x11Ultr_sensor_1_507\x12\x19\n\x11uiuss9_tof_direct\x18\x01 \x01(\x01\x12\x19\n\x11uiuss8_tof_direct\x18\x02 \x01(\x01\x12\x1a\n\x12uiuss11_tof_direct\x18\x03 \x01(\x01\x12\x1a\n\x12uiuss10_tof_direct\x18\x04 \x01(\x01\"\x89\x01\n\x11Ultr_sensor_2_508\x12\x1b\n\x13uiuss9_tof_indirect\x18\x01 \x01(\x01\x12\x1b\n\x13uiuss8_tof_indirect\x18\x02 \x01(\x01\x12\x1c\n\x14uiuss11_tof_indirect\x18\x03 \x01(\x01\x12\x1c\n\x14uiuss10_tof_indirect\x18\x04 \x01(\x01\"\x7f\n\x11Ultr_sensor_3_509\x12\x19\n\x11uiuss5_tof_direct\x18\x01 \x01(\x01\x12\x19\n\x11uiuss4_tof_direct\x18\x02 \x01(\x01\x12\x19\n\x11uiuss3_tof_direct\x18\x03 \x01(\x01\x12\x19\n\x11uiuss2_tof_direct\x18\x04 \x01(\x01\"\x87\x01\n\x11Ultr_sensor_4_510\x12\x1b\n\x13uiuss5_tof_indirect\x18\x01 \x01(\x01\x12\x1b\n\x13uiuss4_tof_indirect\x18\x02 \x01(\x01\x12\x1b\n\x13uiuss3_tof_indirect\x18\x03 \x01(\x01\x12\x1b\n\x13uiuss2_tof_indirect\x18\x04 \x01(\x01\"\x7f\n\x11Ultr_sensor_5_511\x12\x19\n\x11uiuss7_tof_direct\x18\x01 \x01(\x01\x12\x19\n\x11uiuss6_tof_direct\x18\x02 \x01(\x01\x12\x19\n\x11uiuss1_tof_direct\x18\x03 \x01(\x01\x12\x19\n\x11uiuss0_tof_direct\x18\x04 \x01(\x01\"W\n\x0e\x42ms_report_512\x12\x17\n\x0f\x62\x61ttery_current\x18\x01 \x01(\x01\x12\x17\n\x0f\x62\x61ttery_voltage\x18\x02 \x01(\x01\x12\x13\n\x0b\x62\x61ttery_soc\x18\x03 \x01(\x05\"\xd4\x08\n\x06\x44\x65vkit\x12\x41\n\x14throttle_command_100\x18\x01 \x01(\x0b\x32#.apollo.canbus.Throttle_command_100\x12;\n\x11\x62rake_command_101\x18\x02 \x01(\x0b\x32 .apollo.canbus.Brake_command_101\x12\x41\n\x14steering_command_102\x18\x03 \x01(\x0b\x32#.apollo.canbus.Steering_command_102\x12\x39\n\x10gear_command_103\x18\x04 \x01(\x0b\x32\x1f.apollo.canbus.Gear_command_103\x12\x39\n\x10park_command_104\x18\x05 \x01(\x0b\x32\x1f.apollo.canbus.Park_command_104\x12?\n\x13throttle_report_500\x18\x06 \x01(\x0b\x32\".apollo.canbus.Throttle_report_500\x12\x39\n\x10\x62rake_report_501\x18\x07 \x01(\x0b\x32\x1f.apollo.canbus.Brake_report_501\x12?\n\x13steering_report_502\x18\x08 \x01(\x0b\x32\".apollo.canbus.Steering_report_502\x12\x37\n\x0fgear_report_503\x18\t \x01(\x0b\x32\x1e.apollo.canbus.Gear_report_503\x12\x37\n\x0fpark_report_504\x18\n \x01(\x0b\x32\x1e.apollo.canbus.Park_report_504\x12\x35\n\x0evcu_report_505\x18\x0b \x01(\x0b\x32\x1d.apollo.canbus.Vcu_report_505\x12\x43\n\x15wheelspeed_report_506\x18\x0c \x01(\x0b\x32$.apollo.canbus.Wheelspeed_report_506\x12;\n\x11ultr_sensor_1_507\x18\r \x01(\x0b\x32 .apollo.canbus.Ultr_sensor_1_507\x12;\n\x11ultr_sensor_2_508\x18\x0e \x01(\x0b\x32 .apollo.canbus.Ultr_sensor_2_508\x12;\n\x11ultr_sensor_3_509\x18\x0f \x01(\x0b\x32 .apollo.canbus.Ultr_sensor_3_509\x12;\n\x11ultr_sensor_4_510\x18\x10 \x01(\x0b\x32 .apollo.canbus.Ultr_sensor_4_510\x12;\n\x11ultr_sensor_5_511\x18\x11 \x01(\x0b\x32 .apollo.canbus.Ultr_sensor_5_511\x12\x35\n\x0e\x62ms_report_512\x18\x12 \x01(\x0b\x32\x1d.apollo.canbus.Bms_report_512'
)



_THROTTLE_COMMAND_100_THROTTLE_EN_CTRLTYPE = _descriptor.EnumDescriptor(
  name='Throttle_en_ctrlType',
  full_name='apollo.canbus.Throttle_command_100.Throttle_en_ctrlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_EN_CTRL_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_EN_CTRL_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=236,
  serialized_end=317,
)
_sym_db.RegisterEnumDescriptor(_THROTTLE_COMMAND_100_THROTTLE_EN_CTRLTYPE)

_BRAKE_COMMAND_101_AEB_EN_CTRLTYPE = _descriptor.EnumDescriptor(
  name='Aeb_en_ctrlType',
  full_name='apollo.canbus.Brake_command_101.Aeb_en_ctrlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AEB_EN_CTRL_DISABLE_AEB', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AEB_EN_CTRL_ENABLE_AEB', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=556,
  serialized_end=630,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_COMMAND_101_AEB_EN_CTRLTYPE)

_BRAKE_COMMAND_101_BRAKE_EN_CTRLTYPE = _descriptor.EnumDescriptor(
  name='Brake_en_ctrlType',
  full_name='apollo.canbus.Brake_command_101.Brake_en_ctrlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKE_EN_CTRL_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_EN_CTRL_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=632,
  serialized_end=704,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_COMMAND_101_BRAKE_EN_CTRLTYPE)

_STEERING_COMMAND_102_STEER_EN_CTRLTYPE = _descriptor.EnumDescriptor(
  name='Steer_en_ctrlType',
  full_name='apollo.canbus.Steering_command_102.Steer_en_ctrlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEER_EN_CTRL_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEER_EN_CTRL_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=884,
  serialized_end=956,
)
_sym_db.RegisterEnumDescriptor(_STEERING_COMMAND_102_STEER_EN_CTRLTYPE)

_GEAR_COMMAND_103_GEAR_TARGETTYPE = _descriptor.EnumDescriptor(
  name='Gear_targetType',
  full_name='apollo.canbus.Gear_command_103.Gear_targetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_TARGET_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_TARGET_PARK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_TARGET_REVERSE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_TARGET_NEUTRAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_TARGET_DRIVE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1144,
  serialized_end=1281,
)
_sym_db.RegisterEnumDescriptor(_GEAR_COMMAND_103_GEAR_TARGETTYPE)

_GEAR_COMMAND_103_GEAR_EN_CTRLTYPE = _descriptor.EnumDescriptor(
  name='Gear_en_ctrlType',
  full_name='apollo.canbus.Gear_command_103.Gear_en_ctrlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_EN_CTRL_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_EN_CTRL_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1283,
  serialized_end=1352,
)
_sym_db.RegisterEnumDescriptor(_GEAR_COMMAND_103_GEAR_EN_CTRLTYPE)

_PARK_COMMAND_104_PARK_TARGETTYPE = _descriptor.EnumDescriptor(
  name='Park_targetType',
  full_name='apollo.canbus.Park_command_104.Park_targetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARK_TARGET_RELEASE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARK_TARGET_PARKING_TRIGGER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1539,
  serialized_end=1614,
)
_sym_db.RegisterEnumDescriptor(_PARK_COMMAND_104_PARK_TARGETTYPE)

_PARK_COMMAND_104_PARK_EN_CTRLTYPE = _descriptor.EnumDescriptor(
  name='Park_en_ctrlType',
  full_name='apollo.canbus.Park_command_104.Park_en_ctrlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARK_EN_CTRL_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARK_EN_CTRL_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1616,
  serialized_end=1685,
)
_sym_db.RegisterEnumDescriptor(_PARK_COMMAND_104_PARK_EN_CTRLTYPE)

_THROTTLE_REPORT_500_THROTTLE_FLT2TYPE = _descriptor.EnumDescriptor(
  name='Throttle_flt2Type',
  full_name='apollo.canbus.Throttle_report_500.Throttle_flt2Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_FLT2_NO_FAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_FLT2_DRIVE_SYSTEM_COMUNICATION_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1981,
  serialized_end=2079,
)
_sym_db.RegisterEnumDescriptor(_THROTTLE_REPORT_500_THROTTLE_FLT2TYPE)

_THROTTLE_REPORT_500_THROTTLE_FLT1TYPE = _descriptor.EnumDescriptor(
  name='Throttle_flt1Type',
  full_name='apollo.canbus.Throttle_report_500.Throttle_flt1Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_FLT1_NO_FAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_FLT1_DRIVE_SYSTEM_HARDWARE_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2081,
  serialized_end=2175,
)
_sym_db.RegisterEnumDescriptor(_THROTTLE_REPORT_500_THROTTLE_FLT1TYPE)

_THROTTLE_REPORT_500_THROTTLE_EN_STATETYPE = _descriptor.EnumDescriptor(
  name='Throttle_en_stateType',
  full_name='apollo.canbus.Throttle_report_500.Throttle_en_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_EN_STATE_MANUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_EN_STATE_AUTO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_EN_STATE_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_EN_STATE_STANDBY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2178,
  serialized_end=2322,
)
_sym_db.RegisterEnumDescriptor(_THROTTLE_REPORT_500_THROTTLE_EN_STATETYPE)

_BRAKE_REPORT_501_BRAKE_FLT2TYPE = _descriptor.EnumDescriptor(
  name='Brake_flt2Type',
  full_name='apollo.canbus.Brake_report_501.Brake_flt2Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKE_FLT2_NO_FAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_FLT2_BRAKE_SYSTEM_COMUNICATION_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2585,
  serialized_end=2674,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_REPORT_501_BRAKE_FLT2TYPE)

_BRAKE_REPORT_501_BRAKE_FLT1TYPE = _descriptor.EnumDescriptor(
  name='Brake_flt1Type',
  full_name='apollo.canbus.Brake_report_501.Brake_flt1Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKE_FLT1_NO_FAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_FLT1_BRAKE_SYSTEM_HARDWARE_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2676,
  serialized_end=2761,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_REPORT_501_BRAKE_FLT1TYPE)

_BRAKE_REPORT_501_BRAKE_EN_STATETYPE = _descriptor.EnumDescriptor(
  name='Brake_en_stateType',
  full_name='apollo.canbus.Brake_report_501.Brake_en_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKE_EN_STATE_MANUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_EN_STATE_AUTO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_EN_STATE_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_EN_STATE_STANDBY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2764,
  serialized_end=2893,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_REPORT_501_BRAKE_EN_STATETYPE)

_STEERING_REPORT_502_STEER_FLT2TYPE = _descriptor.EnumDescriptor(
  name='Steer_flt2Type',
  full_name='apollo.canbus.Steering_report_502.Steer_flt2Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEER_FLT2_NO_FAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEER_FLT2_STEER_SYSTEM_COMUNICATION_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3200,
  serialized_end=3289,
)
_sym_db.RegisterEnumDescriptor(_STEERING_REPORT_502_STEER_FLT2TYPE)

_STEERING_REPORT_502_STEER_FLT1TYPE = _descriptor.EnumDescriptor(
  name='Steer_flt1Type',
  full_name='apollo.canbus.Steering_report_502.Steer_flt1Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEER_FLT1_NO_FAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEER_FLT1_STEER_SYSTEM_HARDWARE_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3291,
  serialized_end=3376,
)
_sym_db.RegisterEnumDescriptor(_STEERING_REPORT_502_STEER_FLT1TYPE)

_STEERING_REPORT_502_STEER_EN_STATETYPE = _descriptor.EnumDescriptor(
  name='Steer_en_stateType',
  full_name='apollo.canbus.Steering_report_502.Steer_en_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEER_EN_STATE_MANUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEER_EN_STATE_AUTO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEER_EN_STATE_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEER_EN_STATE_STANDBY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3379,
  serialized_end=3508,
)
_sym_db.RegisterEnumDescriptor(_STEERING_REPORT_502_STEER_EN_STATETYPE)

_GEAR_REPORT_503_GEAR_FLTTYPE = _descriptor.EnumDescriptor(
  name='Gear_fltType',
  full_name='apollo.canbus.Gear_report_503.Gear_fltType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_FLT_NO_FAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_FLT_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3662,
  serialized_end=3719,
)
_sym_db.RegisterEnumDescriptor(_GEAR_REPORT_503_GEAR_FLTTYPE)

_GEAR_REPORT_503_GEAR_ACTUALTYPE = _descriptor.EnumDescriptor(
  name='Gear_actualType',
  full_name='apollo.canbus.Gear_report_503.Gear_actualType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_ACTUAL_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_ACTUAL_PARK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_ACTUAL_REVERSE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_ACTUAL_NEUTRAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_ACTUAL_DRIVE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3722,
  serialized_end=3859,
)
_sym_db.RegisterEnumDescriptor(_GEAR_REPORT_503_GEAR_ACTUALTYPE)

_PARK_REPORT_504_PARKING_ACTUALTYPE = _descriptor.EnumDescriptor(
  name='Parking_actualType',
  full_name='apollo.canbus.Park_report_504.Parking_actualType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARKING_ACTUAL_RELEASE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_ACTUAL_PARKING_TRIGGER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4019,
  serialized_end=4103,
)
_sym_db.RegisterEnumDescriptor(_PARK_REPORT_504_PARKING_ACTUALTYPE)

_PARK_REPORT_504_PARK_FLTTYPE = _descriptor.EnumDescriptor(
  name='Park_fltType',
  full_name='apollo.canbus.Park_report_504.Park_fltType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARK_FLT_NO_FAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARK_FLT_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4105,
  serialized_end=4162,
)
_sym_db.RegisterEnumDescriptor(_PARK_REPORT_504_PARK_FLTTYPE)

_VCU_REPORT_505_VEHICLE_MODE_STATETYPE = _descriptor.EnumDescriptor(
  name='Vehicle_mode_stateType',
  full_name='apollo.canbus.Vcu_report_505.Vehicle_mode_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VEHICLE_MODE_STATE_MANUAL_REMOTE_MODE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEHICLE_MODE_STATE_AUTO_MODE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEHICLE_MODE_STATE_EMERGENCY_MODE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEHICLE_MODE_STATE_STANDBY_MODE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4512,
  serialized_end=4689,
)
_sym_db.RegisterEnumDescriptor(_VCU_REPORT_505_VEHICLE_MODE_STATETYPE)

_VCU_REPORT_505_FRONTCRASH_STATETYPE = _descriptor.EnumDescriptor(
  name='Frontcrash_stateType',
  full_name='apollo.canbus.Vcu_report_505.Frontcrash_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FRONTCRASH_STATE_NO_EVENT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRONTCRASH_STATE_CRASH_EVENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4691,
  serialized_end=4778,
)
_sym_db.RegisterEnumDescriptor(_VCU_REPORT_505_FRONTCRASH_STATETYPE)

_VCU_REPORT_505_BACKCRASH_STATETYPE = _descriptor.EnumDescriptor(
  name='Backcrash_stateType',
  full_name='apollo.canbus.Vcu_report_505.Backcrash_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BACKCRASH_STATE_NO_EVENT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BACKCRASH_STATE_CRASH_EVENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4780,
  serialized_end=4864,
)
_sym_db.RegisterEnumDescriptor(_VCU_REPORT_505_BACKCRASH_STATETYPE)

_VCU_REPORT_505_AEB_STATETYPE = _descriptor.EnumDescriptor(
  name='Aeb_stateType',
  full_name='apollo.canbus.Vcu_report_505.Aeb_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AEB_STATE_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AEB_STATE_ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4866,
  serialized_end=4927,
)
_sym_db.RegisterEnumDescriptor(_VCU_REPORT_505_AEB_STATETYPE)


_THROTTLE_COMMAND_100 = _descriptor.Descriptor(
  name='Throttle_command_100',
  full_name='apollo.canbus.Throttle_command_100',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='throttle_acc', full_name='apollo.canbus.Throttle_command_100.throttle_acc', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum_100', full_name='apollo.canbus.Throttle_command_100.checksum_100', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_pedal_target', full_name='apollo.canbus.Throttle_command_100.throttle_pedal_target', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_en_ctrl', full_name='apollo.canbus.Throttle_command_100.throttle_en_ctrl', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _THROTTLE_COMMAND_100_THROTTLE_EN_CTRLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=317,
)


_BRAKE_COMMAND_101 = _descriptor.Descriptor(
  name='Brake_command_101',
  full_name='apollo.canbus.Brake_command_101',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brake_dec', full_name='apollo.canbus.Brake_command_101.brake_dec', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum_101', full_name='apollo.canbus.Brake_command_101.checksum_101', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_pedal_target', full_name='apollo.canbus.Brake_command_101.brake_pedal_target', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_en_ctrl', full_name='apollo.canbus.Brake_command_101.brake_en_ctrl', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aeb_en_ctrl', full_name='apollo.canbus.Brake_command_101.aeb_en_ctrl', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BRAKE_COMMAND_101_AEB_EN_CTRLTYPE,
    _BRAKE_COMMAND_101_BRAKE_EN_CTRLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=704,
)


_STEERING_COMMAND_102 = _descriptor.Descriptor(
  name='Steering_command_102',
  full_name='apollo.canbus.Steering_command_102',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steer_en_ctrl', full_name='apollo.canbus.Steering_command_102.steer_en_ctrl', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_target', full_name='apollo.canbus.Steering_command_102.steer_angle_target', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_spd', full_name='apollo.canbus.Steering_command_102.steer_angle_spd', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum_102', full_name='apollo.canbus.Steering_command_102.checksum_102', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STEERING_COMMAND_102_STEER_EN_CTRLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=707,
  serialized_end=956,
)


_GEAR_COMMAND_103 = _descriptor.Descriptor(
  name='Gear_command_103',
  full_name='apollo.canbus.Gear_command_103',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gear_target', full_name='apollo.canbus.Gear_command_103.gear_target', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_en_ctrl', full_name='apollo.canbus.Gear_command_103.gear_en_ctrl', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum_103', full_name='apollo.canbus.Gear_command_103.checksum_103', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GEAR_COMMAND_103_GEAR_TARGETTYPE,
    _GEAR_COMMAND_103_GEAR_EN_CTRLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=959,
  serialized_end=1352,
)


_PARK_COMMAND_104 = _descriptor.Descriptor(
  name='Park_command_104',
  full_name='apollo.canbus.Park_command_104',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='checksum_104', full_name='apollo.canbus.Park_command_104.checksum_104', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='park_target', full_name='apollo.canbus.Park_command_104.park_target', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='park_en_ctrl', full_name='apollo.canbus.Park_command_104.park_en_ctrl', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PARK_COMMAND_104_PARK_TARGETTYPE,
    _PARK_COMMAND_104_PARK_EN_CTRLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1355,
  serialized_end=1685,
)


_THROTTLE_REPORT_500 = _descriptor.Descriptor(
  name='Throttle_report_500',
  full_name='apollo.canbus.Throttle_report_500',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='throttle_pedal_actual', full_name='apollo.canbus.Throttle_report_500.throttle_pedal_actual', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_flt2', full_name='apollo.canbus.Throttle_report_500.throttle_flt2', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_flt1', full_name='apollo.canbus.Throttle_report_500.throttle_flt1', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_en_state', full_name='apollo.canbus.Throttle_report_500.throttle_en_state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _THROTTLE_REPORT_500_THROTTLE_FLT2TYPE,
    _THROTTLE_REPORT_500_THROTTLE_FLT1TYPE,
    _THROTTLE_REPORT_500_THROTTLE_EN_STATETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1688,
  serialized_end=2322,
)


_BRAKE_REPORT_501 = _descriptor.Descriptor(
  name='Brake_report_501',
  full_name='apollo.canbus.Brake_report_501',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brake_pedal_actual', full_name='apollo.canbus.Brake_report_501.brake_pedal_actual', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_flt2', full_name='apollo.canbus.Brake_report_501.brake_flt2', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_flt1', full_name='apollo.canbus.Brake_report_501.brake_flt1', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_en_state', full_name='apollo.canbus.Brake_report_501.brake_en_state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BRAKE_REPORT_501_BRAKE_FLT2TYPE,
    _BRAKE_REPORT_501_BRAKE_FLT1TYPE,
    _BRAKE_REPORT_501_BRAKE_EN_STATETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2325,
  serialized_end=2893,
)


_STEERING_REPORT_502 = _descriptor.Descriptor(
  name='Steering_report_502',
  full_name='apollo.canbus.Steering_report_502',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steer_angle_spd_actual', full_name='apollo.canbus.Steering_report_502.steer_angle_spd_actual', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_flt2', full_name='apollo.canbus.Steering_report_502.steer_flt2', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_flt1', full_name='apollo.canbus.Steering_report_502.steer_flt1', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_en_state', full_name='apollo.canbus.Steering_report_502.steer_en_state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_actual', full_name='apollo.canbus.Steering_report_502.steer_angle_actual', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STEERING_REPORT_502_STEER_FLT2TYPE,
    _STEERING_REPORT_502_STEER_FLT1TYPE,
    _STEERING_REPORT_502_STEER_EN_STATETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2896,
  serialized_end=3508,
)


_GEAR_REPORT_503 = _descriptor.Descriptor(
  name='Gear_report_503',
  full_name='apollo.canbus.Gear_report_503',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gear_flt', full_name='apollo.canbus.Gear_report_503.gear_flt', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_actual', full_name='apollo.canbus.Gear_report_503.gear_actual', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GEAR_REPORT_503_GEAR_FLTTYPE,
    _GEAR_REPORT_503_GEAR_ACTUALTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3511,
  serialized_end=3859,
)


_PARK_REPORT_504 = _descriptor.Descriptor(
  name='Park_report_504',
  full_name='apollo.canbus.Park_report_504',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parking_actual', full_name='apollo.canbus.Park_report_504.parking_actual', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='park_flt', full_name='apollo.canbus.Park_report_504.park_flt', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PARK_REPORT_504_PARKING_ACTUALTYPE,
    _PARK_REPORT_504_PARK_FLTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3862,
  serialized_end=4162,
)


_VCU_REPORT_505 = _descriptor.Descriptor(
  name='Vcu_report_505',
  full_name='apollo.canbus.Vcu_report_505',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_mode_state', full_name='apollo.canbus.Vcu_report_505.vehicle_mode_state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frontcrash_state', full_name='apollo.canbus.Vcu_report_505.frontcrash_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backcrash_state', full_name='apollo.canbus.Vcu_report_505.backcrash_state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aeb_state', full_name='apollo.canbus.Vcu_report_505.aeb_state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc', full_name='apollo.canbus.Vcu_report_505.acc', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='apollo.canbus.Vcu_report_505.speed', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VCU_REPORT_505_VEHICLE_MODE_STATETYPE,
    _VCU_REPORT_505_FRONTCRASH_STATETYPE,
    _VCU_REPORT_505_BACKCRASH_STATETYPE,
    _VCU_REPORT_505_AEB_STATETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4165,
  serialized_end=4927,
)


_WHEELSPEED_REPORT_506 = _descriptor.Descriptor(
  name='Wheelspeed_report_506',
  full_name='apollo.canbus.Wheelspeed_report_506',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rr', full_name='apollo.canbus.Wheelspeed_report_506.rr', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rl', full_name='apollo.canbus.Wheelspeed_report_506.rl', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fr', full_name='apollo.canbus.Wheelspeed_report_506.fr', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fl', full_name='apollo.canbus.Wheelspeed_report_506.fl', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4929,
  serialized_end=5000,
)


_ULTR_SENSOR_1_507 = _descriptor.Descriptor(
  name='Ultr_sensor_1_507',
  full_name='apollo.canbus.Ultr_sensor_1_507',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uiuss9_tof_direct', full_name='apollo.canbus.Ultr_sensor_1_507.uiuss9_tof_direct', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss8_tof_direct', full_name='apollo.canbus.Ultr_sensor_1_507.uiuss8_tof_direct', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss11_tof_direct', full_name='apollo.canbus.Ultr_sensor_1_507.uiuss11_tof_direct', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss10_tof_direct', full_name='apollo.canbus.Ultr_sensor_1_507.uiuss10_tof_direct', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5003,
  serialized_end=5132,
)


_ULTR_SENSOR_2_508 = _descriptor.Descriptor(
  name='Ultr_sensor_2_508',
  full_name='apollo.canbus.Ultr_sensor_2_508',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uiuss9_tof_indirect', full_name='apollo.canbus.Ultr_sensor_2_508.uiuss9_tof_indirect', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss8_tof_indirect', full_name='apollo.canbus.Ultr_sensor_2_508.uiuss8_tof_indirect', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss11_tof_indirect', full_name='apollo.canbus.Ultr_sensor_2_508.uiuss11_tof_indirect', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss10_tof_indirect', full_name='apollo.canbus.Ultr_sensor_2_508.uiuss10_tof_indirect', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5135,
  serialized_end=5272,
)


_ULTR_SENSOR_3_509 = _descriptor.Descriptor(
  name='Ultr_sensor_3_509',
  full_name='apollo.canbus.Ultr_sensor_3_509',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uiuss5_tof_direct', full_name='apollo.canbus.Ultr_sensor_3_509.uiuss5_tof_direct', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss4_tof_direct', full_name='apollo.canbus.Ultr_sensor_3_509.uiuss4_tof_direct', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss3_tof_direct', full_name='apollo.canbus.Ultr_sensor_3_509.uiuss3_tof_direct', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss2_tof_direct', full_name='apollo.canbus.Ultr_sensor_3_509.uiuss2_tof_direct', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5274,
  serialized_end=5401,
)


_ULTR_SENSOR_4_510 = _descriptor.Descriptor(
  name='Ultr_sensor_4_510',
  full_name='apollo.canbus.Ultr_sensor_4_510',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uiuss5_tof_indirect', full_name='apollo.canbus.Ultr_sensor_4_510.uiuss5_tof_indirect', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss4_tof_indirect', full_name='apollo.canbus.Ultr_sensor_4_510.uiuss4_tof_indirect', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss3_tof_indirect', full_name='apollo.canbus.Ultr_sensor_4_510.uiuss3_tof_indirect', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss2_tof_indirect', full_name='apollo.canbus.Ultr_sensor_4_510.uiuss2_tof_indirect', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5404,
  serialized_end=5539,
)


_ULTR_SENSOR_5_511 = _descriptor.Descriptor(
  name='Ultr_sensor_5_511',
  full_name='apollo.canbus.Ultr_sensor_5_511',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uiuss7_tof_direct', full_name='apollo.canbus.Ultr_sensor_5_511.uiuss7_tof_direct', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss6_tof_direct', full_name='apollo.canbus.Ultr_sensor_5_511.uiuss6_tof_direct', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss1_tof_direct', full_name='apollo.canbus.Ultr_sensor_5_511.uiuss1_tof_direct', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uiuss0_tof_direct', full_name='apollo.canbus.Ultr_sensor_5_511.uiuss0_tof_direct', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5541,
  serialized_end=5668,
)


_BMS_REPORT_512 = _descriptor.Descriptor(
  name='Bms_report_512',
  full_name='apollo.canbus.Bms_report_512',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='battery_current', full_name='apollo.canbus.Bms_report_512.battery_current', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery_voltage', full_name='apollo.canbus.Bms_report_512.battery_voltage', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery_soc', full_name='apollo.canbus.Bms_report_512.battery_soc', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5670,
  serialized_end=5757,
)


_DEVKIT = _descriptor.Descriptor(
  name='Devkit',
  full_name='apollo.canbus.Devkit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='throttle_command_100', full_name='apollo.canbus.Devkit.throttle_command_100', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_command_101', full_name='apollo.canbus.Devkit.brake_command_101', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_command_102', full_name='apollo.canbus.Devkit.steering_command_102', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_command_103', full_name='apollo.canbus.Devkit.gear_command_103', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='park_command_104', full_name='apollo.canbus.Devkit.park_command_104', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_report_500', full_name='apollo.canbus.Devkit.throttle_report_500', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_report_501', full_name='apollo.canbus.Devkit.brake_report_501', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_report_502', full_name='apollo.canbus.Devkit.steering_report_502', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_report_503', full_name='apollo.canbus.Devkit.gear_report_503', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='park_report_504', full_name='apollo.canbus.Devkit.park_report_504', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_report_505', full_name='apollo.canbus.Devkit.vcu_report_505', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelspeed_report_506', full_name='apollo.canbus.Devkit.wheelspeed_report_506', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ultr_sensor_1_507', full_name='apollo.canbus.Devkit.ultr_sensor_1_507', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ultr_sensor_2_508', full_name='apollo.canbus.Devkit.ultr_sensor_2_508', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ultr_sensor_3_509', full_name='apollo.canbus.Devkit.ultr_sensor_3_509', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ultr_sensor_4_510', full_name='apollo.canbus.Devkit.ultr_sensor_4_510', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ultr_sensor_5_511', full_name='apollo.canbus.Devkit.ultr_sensor_5_511', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bms_report_512', full_name='apollo.canbus.Devkit.bms_report_512', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5760,
  serialized_end=6868,
)

_THROTTLE_COMMAND_100.fields_by_name['throttle_en_ctrl'].enum_type = _THROTTLE_COMMAND_100_THROTTLE_EN_CTRLTYPE
_THROTTLE_COMMAND_100_THROTTLE_EN_CTRLTYPE.containing_type = _THROTTLE_COMMAND_100
_BRAKE_COMMAND_101.fields_by_name['brake_en_ctrl'].enum_type = _BRAKE_COMMAND_101_BRAKE_EN_CTRLTYPE
_BRAKE_COMMAND_101.fields_by_name['aeb_en_ctrl'].enum_type = _BRAKE_COMMAND_101_AEB_EN_CTRLTYPE
_BRAKE_COMMAND_101_AEB_EN_CTRLTYPE.containing_type = _BRAKE_COMMAND_101
_BRAKE_COMMAND_101_BRAKE_EN_CTRLTYPE.containing_type = _BRAKE_COMMAND_101
_STEERING_COMMAND_102.fields_by_name['steer_en_ctrl'].enum_type = _STEERING_COMMAND_102_STEER_EN_CTRLTYPE
_STEERING_COMMAND_102_STEER_EN_CTRLTYPE.containing_type = _STEERING_COMMAND_102
_GEAR_COMMAND_103.fields_by_name['gear_target'].enum_type = _GEAR_COMMAND_103_GEAR_TARGETTYPE
_GEAR_COMMAND_103.fields_by_name['gear_en_ctrl'].enum_type = _GEAR_COMMAND_103_GEAR_EN_CTRLTYPE
_GEAR_COMMAND_103_GEAR_TARGETTYPE.containing_type = _GEAR_COMMAND_103
_GEAR_COMMAND_103_GEAR_EN_CTRLTYPE.containing_type = _GEAR_COMMAND_103
_PARK_COMMAND_104.fields_by_name['park_target'].enum_type = _PARK_COMMAND_104_PARK_TARGETTYPE
_PARK_COMMAND_104.fields_by_name['park_en_ctrl'].enum_type = _PARK_COMMAND_104_PARK_EN_CTRLTYPE
_PARK_COMMAND_104_PARK_TARGETTYPE.containing_type = _PARK_COMMAND_104
_PARK_COMMAND_104_PARK_EN_CTRLTYPE.containing_type = _PARK_COMMAND_104
_THROTTLE_REPORT_500.fields_by_name['throttle_flt2'].enum_type = _THROTTLE_REPORT_500_THROTTLE_FLT2TYPE
_THROTTLE_REPORT_500.fields_by_name['throttle_flt1'].enum_type = _THROTTLE_REPORT_500_THROTTLE_FLT1TYPE
_THROTTLE_REPORT_500.fields_by_name['throttle_en_state'].enum_type = _THROTTLE_REPORT_500_THROTTLE_EN_STATETYPE
_THROTTLE_REPORT_500_THROTTLE_FLT2TYPE.containing_type = _THROTTLE_REPORT_500
_THROTTLE_REPORT_500_THROTTLE_FLT1TYPE.containing_type = _THROTTLE_REPORT_500
_THROTTLE_REPORT_500_THROTTLE_EN_STATETYPE.containing_type = _THROTTLE_REPORT_500
_BRAKE_REPORT_501.fields_by_name['brake_flt2'].enum_type = _BRAKE_REPORT_501_BRAKE_FLT2TYPE
_BRAKE_REPORT_501.fields_by_name['brake_flt1'].enum_type = _BRAKE_REPORT_501_BRAKE_FLT1TYPE
_BRAKE_REPORT_501.fields_by_name['brake_en_state'].enum_type = _BRAKE_REPORT_501_BRAKE_EN_STATETYPE
_BRAKE_REPORT_501_BRAKE_FLT2TYPE.containing_type = _BRAKE_REPORT_501
_BRAKE_REPORT_501_BRAKE_FLT1TYPE.containing_type = _BRAKE_REPORT_501
_BRAKE_REPORT_501_BRAKE_EN_STATETYPE.containing_type = _BRAKE_REPORT_501
_STEERING_REPORT_502.fields_by_name['steer_flt2'].enum_type = _STEERING_REPORT_502_STEER_FLT2TYPE
_STEERING_REPORT_502.fields_by_name['steer_flt1'].enum_type = _STEERING_REPORT_502_STEER_FLT1TYPE
_STEERING_REPORT_502.fields_by_name['steer_en_state'].enum_type = _STEERING_REPORT_502_STEER_EN_STATETYPE
_STEERING_REPORT_502_STEER_FLT2TYPE.containing_type = _STEERING_REPORT_502
_STEERING_REPORT_502_STEER_FLT1TYPE.containing_type = _STEERING_REPORT_502
_STEERING_REPORT_502_STEER_EN_STATETYPE.containing_type = _STEERING_REPORT_502
_GEAR_REPORT_503.fields_by_name['gear_flt'].enum_type = _GEAR_REPORT_503_GEAR_FLTTYPE
_GEAR_REPORT_503.fields_by_name['gear_actual'].enum_type = _GEAR_REPORT_503_GEAR_ACTUALTYPE
_GEAR_REPORT_503_GEAR_FLTTYPE.containing_type = _GEAR_REPORT_503
_GEAR_REPORT_503_GEAR_ACTUALTYPE.containing_type = _GEAR_REPORT_503
_PARK_REPORT_504.fields_by_name['parking_actual'].enum_type = _PARK_REPORT_504_PARKING_ACTUALTYPE
_PARK_REPORT_504.fields_by_name['park_flt'].enum_type = _PARK_REPORT_504_PARK_FLTTYPE
_PARK_REPORT_504_PARKING_ACTUALTYPE.containing_type = _PARK_REPORT_504
_PARK_REPORT_504_PARK_FLTTYPE.containing_type = _PARK_REPORT_504
_VCU_REPORT_505.fields_by_name['vehicle_mode_state'].enum_type = _VCU_REPORT_505_VEHICLE_MODE_STATETYPE
_VCU_REPORT_505.fields_by_name['frontcrash_state'].enum_type = _VCU_REPORT_505_FRONTCRASH_STATETYPE
_VCU_REPORT_505.fields_by_name['backcrash_state'].enum_type = _VCU_REPORT_505_BACKCRASH_STATETYPE
_VCU_REPORT_505.fields_by_name['aeb_state'].enum_type = _VCU_REPORT_505_AEB_STATETYPE
_VCU_REPORT_505_VEHICLE_MODE_STATETYPE.containing_type = _VCU_REPORT_505
_VCU_REPORT_505_FRONTCRASH_STATETYPE.containing_type = _VCU_REPORT_505
_VCU_REPORT_505_BACKCRASH_STATETYPE.containing_type = _VCU_REPORT_505
_VCU_REPORT_505_AEB_STATETYPE.containing_type = _VCU_REPORT_505
_DEVKIT.fields_by_name['throttle_command_100'].message_type = _THROTTLE_COMMAND_100
_DEVKIT.fields_by_name['brake_command_101'].message_type = _BRAKE_COMMAND_101
_DEVKIT.fields_by_name['steering_command_102'].message_type = _STEERING_COMMAND_102
_DEVKIT.fields_by_name['gear_command_103'].message_type = _GEAR_COMMAND_103
_DEVKIT.fields_by_name['park_command_104'].message_type = _PARK_COMMAND_104
_DEVKIT.fields_by_name['throttle_report_500'].message_type = _THROTTLE_REPORT_500
_DEVKIT.fields_by_name['brake_report_501'].message_type = _BRAKE_REPORT_501
_DEVKIT.fields_by_name['steering_report_502'].message_type = _STEERING_REPORT_502
_DEVKIT.fields_by_name['gear_report_503'].message_type = _GEAR_REPORT_503
_DEVKIT.fields_by_name['park_report_504'].message_type = _PARK_REPORT_504
_DEVKIT.fields_by_name['vcu_report_505'].message_type = _VCU_REPORT_505
_DEVKIT.fields_by_name['wheelspeed_report_506'].message_type = _WHEELSPEED_REPORT_506
_DEVKIT.fields_by_name['ultr_sensor_1_507'].message_type = _ULTR_SENSOR_1_507
_DEVKIT.fields_by_name['ultr_sensor_2_508'].message_type = _ULTR_SENSOR_2_508
_DEVKIT.fields_by_name['ultr_sensor_3_509'].message_type = _ULTR_SENSOR_3_509
_DEVKIT.fields_by_name['ultr_sensor_4_510'].message_type = _ULTR_SENSOR_4_510
_DEVKIT.fields_by_name['ultr_sensor_5_511'].message_type = _ULTR_SENSOR_5_511
_DEVKIT.fields_by_name['bms_report_512'].message_type = _BMS_REPORT_512
DESCRIPTOR.message_types_by_name['Throttle_command_100'] = _THROTTLE_COMMAND_100
DESCRIPTOR.message_types_by_name['Brake_command_101'] = _BRAKE_COMMAND_101
DESCRIPTOR.message_types_by_name['Steering_command_102'] = _STEERING_COMMAND_102
DESCRIPTOR.message_types_by_name['Gear_command_103'] = _GEAR_COMMAND_103
DESCRIPTOR.message_types_by_name['Park_command_104'] = _PARK_COMMAND_104
DESCRIPTOR.message_types_by_name['Throttle_report_500'] = _THROTTLE_REPORT_500
DESCRIPTOR.message_types_by_name['Brake_report_501'] = _BRAKE_REPORT_501
DESCRIPTOR.message_types_by_name['Steering_report_502'] = _STEERING_REPORT_502
DESCRIPTOR.message_types_by_name['Gear_report_503'] = _GEAR_REPORT_503
DESCRIPTOR.message_types_by_name['Park_report_504'] = _PARK_REPORT_504
DESCRIPTOR.message_types_by_name['Vcu_report_505'] = _VCU_REPORT_505
DESCRIPTOR.message_types_by_name['Wheelspeed_report_506'] = _WHEELSPEED_REPORT_506
DESCRIPTOR.message_types_by_name['Ultr_sensor_1_507'] = _ULTR_SENSOR_1_507
DESCRIPTOR.message_types_by_name['Ultr_sensor_2_508'] = _ULTR_SENSOR_2_508
DESCRIPTOR.message_types_by_name['Ultr_sensor_3_509'] = _ULTR_SENSOR_3_509
DESCRIPTOR.message_types_by_name['Ultr_sensor_4_510'] = _ULTR_SENSOR_4_510
DESCRIPTOR.message_types_by_name['Ultr_sensor_5_511'] = _ULTR_SENSOR_5_511
DESCRIPTOR.message_types_by_name['Bms_report_512'] = _BMS_REPORT_512
DESCRIPTOR.message_types_by_name['Devkit'] = _DEVKIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Throttle_command_100 = _reflection.GeneratedProtocolMessageType('Throttle_command_100', (_message.Message,), {
  'DESCRIPTOR' : _THROTTLE_COMMAND_100,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Throttle_command_100)
  })
_sym_db.RegisterMessage(Throttle_command_100)

Brake_command_101 = _reflection.GeneratedProtocolMessageType('Brake_command_101', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_COMMAND_101,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_command_101)
  })
_sym_db.RegisterMessage(Brake_command_101)

Steering_command_102 = _reflection.GeneratedProtocolMessageType('Steering_command_102', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_COMMAND_102,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_command_102)
  })
_sym_db.RegisterMessage(Steering_command_102)

Gear_command_103 = _reflection.GeneratedProtocolMessageType('Gear_command_103', (_message.Message,), {
  'DESCRIPTOR' : _GEAR_COMMAND_103,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Gear_command_103)
  })
_sym_db.RegisterMessage(Gear_command_103)

Park_command_104 = _reflection.GeneratedProtocolMessageType('Park_command_104', (_message.Message,), {
  'DESCRIPTOR' : _PARK_COMMAND_104,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Park_command_104)
  })
_sym_db.RegisterMessage(Park_command_104)

Throttle_report_500 = _reflection.GeneratedProtocolMessageType('Throttle_report_500', (_message.Message,), {
  'DESCRIPTOR' : _THROTTLE_REPORT_500,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Throttle_report_500)
  })
_sym_db.RegisterMessage(Throttle_report_500)

Brake_report_501 = _reflection.GeneratedProtocolMessageType('Brake_report_501', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_REPORT_501,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_report_501)
  })
_sym_db.RegisterMessage(Brake_report_501)

Steering_report_502 = _reflection.GeneratedProtocolMessageType('Steering_report_502', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_REPORT_502,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_report_502)
  })
_sym_db.RegisterMessage(Steering_report_502)

Gear_report_503 = _reflection.GeneratedProtocolMessageType('Gear_report_503', (_message.Message,), {
  'DESCRIPTOR' : _GEAR_REPORT_503,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Gear_report_503)
  })
_sym_db.RegisterMessage(Gear_report_503)

Park_report_504 = _reflection.GeneratedProtocolMessageType('Park_report_504', (_message.Message,), {
  'DESCRIPTOR' : _PARK_REPORT_504,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Park_report_504)
  })
_sym_db.RegisterMessage(Park_report_504)

Vcu_report_505 = _reflection.GeneratedProtocolMessageType('Vcu_report_505', (_message.Message,), {
  'DESCRIPTOR' : _VCU_REPORT_505,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vcu_report_505)
  })
_sym_db.RegisterMessage(Vcu_report_505)

Wheelspeed_report_506 = _reflection.GeneratedProtocolMessageType('Wheelspeed_report_506', (_message.Message,), {
  'DESCRIPTOR' : _WHEELSPEED_REPORT_506,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Wheelspeed_report_506)
  })
_sym_db.RegisterMessage(Wheelspeed_report_506)

Ultr_sensor_1_507 = _reflection.GeneratedProtocolMessageType('Ultr_sensor_1_507', (_message.Message,), {
  'DESCRIPTOR' : _ULTR_SENSOR_1_507,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ultr_sensor_1_507)
  })
_sym_db.RegisterMessage(Ultr_sensor_1_507)

Ultr_sensor_2_508 = _reflection.GeneratedProtocolMessageType('Ultr_sensor_2_508', (_message.Message,), {
  'DESCRIPTOR' : _ULTR_SENSOR_2_508,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ultr_sensor_2_508)
  })
_sym_db.RegisterMessage(Ultr_sensor_2_508)

Ultr_sensor_3_509 = _reflection.GeneratedProtocolMessageType('Ultr_sensor_3_509', (_message.Message,), {
  'DESCRIPTOR' : _ULTR_SENSOR_3_509,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ultr_sensor_3_509)
  })
_sym_db.RegisterMessage(Ultr_sensor_3_509)

Ultr_sensor_4_510 = _reflection.GeneratedProtocolMessageType('Ultr_sensor_4_510', (_message.Message,), {
  'DESCRIPTOR' : _ULTR_SENSOR_4_510,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ultr_sensor_4_510)
  })
_sym_db.RegisterMessage(Ultr_sensor_4_510)

Ultr_sensor_5_511 = _reflection.GeneratedProtocolMessageType('Ultr_sensor_5_511', (_message.Message,), {
  'DESCRIPTOR' : _ULTR_SENSOR_5_511,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ultr_sensor_5_511)
  })
_sym_db.RegisterMessage(Ultr_sensor_5_511)

Bms_report_512 = _reflection.GeneratedProtocolMessageType('Bms_report_512', (_message.Message,), {
  'DESCRIPTOR' : _BMS_REPORT_512,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Bms_report_512)
  })
_sym_db.RegisterMessage(Bms_report_512)

Devkit = _reflection.GeneratedProtocolMessageType('Devkit', (_message.Message,), {
  'DESCRIPTOR' : _DEVKIT,
  '__module__' : 'modules.canbus.proto.devkit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Devkit)
  })
_sym_db.RegisterMessage(Devkit)


# @@protoc_insertion_point(module_scope)
